@@ -21,4 +21,8 @@ class Terminal:
     
     @staticmethod
     def error(s):
-        print(f"> {bcolors.FAIL}ERROR{bcolors.ENDC} - {s}")
\ No newline at end of file
+        print(f"> {bcolors.FAIL}ERROR{bcolors.ENDC} - {s}")
+    
+    @staticmethod
+    def found(s):
+        print(f"> {bcolors.OKGREEN}URL FOUND:{bcolors.ENDC} {s}")
\ No newline at end of file
