@@ -5,17 +5,20 @@ class Response(ResponseType):
     def __init__(self, text, url) -> None:
         self.text = text
         self.url = url
-        self.origin = self.getOrigin()
+        self.subdomain, self.origin = self.getOrigin()
+        
         self.debug_init()
     
     def getOrigin(self):
         try: 
+            
             split = self.url.split(".")
             domain = split[1]
+            subdomain = split[0]
             TLD = split[2].split("/")[0]
-            return domain + "." + TLD
+            return subdomain, domain + "." + TLD
         except:
-            return None
+            return None, None
     
     def debug_init(self):
         Terminal.put(f"{self.url} - {bcolors.OKGREEN}success{bcolors.ENDC}")
