@@ -22,6 +22,7 @@ class Scraper:
         self.date = None
         self.url = resonpse.url
         self.origin = self.response.origin
+        self.subdomain = self.response.subdomain
         self._soup = BeautifulSoup(resonpse.text, features = BS4_FEATURES)
         self.title = self.getTitle()
 
@@ -64,7 +65,7 @@ class Scraper:
         Returns a list of links
         """
         hrefList = List(href)
-        hrefList.extend([href(a['href'], self.origin) for a in self._soup.find_all('a', href = True)])
+        hrefList.extend([href(a['href'], self.origin, self.subdomain) for a in self._soup.find_all('a', href = True)])
         return hrefList
 
     def __str__(self):
